environments

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2026 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

const (
	UnitTestingEnv        string = "unit_testing"
	IntegrationTestingEnv string = "integration_testing"
	DevelopmentEnv        string = "development"
	ProductionEnv         string = "production"

	EnvironmentStringKey string = "OCM_ENV"
	EnvironmentDefault          = DevelopmentEnv

	// Database SSL modes
	SSLModeDisable string = "disable"
)

Variables

This section is empty.

Functions

func ApplyEnvironmentOverrides added in v0.2.0

func ApplyEnvironmentOverrides(cfg *config.ApplicationConfig) error

ApplyEnvironmentOverrides applies environment-specific configuration overrides This is used by the new config system to apply environment-specific settings (e.g., development environment disables JWT and TLS)

func GetEnvironmentStrFromEnv

func GetEnvironmentStrFromEnv() string

Types

type ApplicationConfig

type ApplicationConfig struct {
	ApplicationConfig *config.ApplicationConfig
}

type Clients

type Clients struct {
	OCM *ocm.Client
}

type ConfigDefaults

type ConfigDefaults struct {
	Server   map[string]interface{}
	Metrics  map[string]interface{}
	Database map[string]interface{}
	OCM      map[string]interface{}
	Options  map[string]interface{}
}

type Database

type Database struct {
	SessionFactory db.SessionFactory
}

type Env

type Env struct {
	Handlers Handlers
	Database Database
	Clients  Clients
	Config   *config.ApplicationConfig
	Name     string
	Services Services
}

func Environment

func Environment() *Env

func (*Env) Initialize

func (e *Env) Initialize() error

Initialize loads the environment's resources This should be called after the e.Config has been set appropriately though AddFlags and pasing, done elsewhere The environment does NOT handle flag parsing

func (*Env) LoadClients

func (e *Env) LoadClients() error

func (*Env) LoadServices

func (e *Env) LoadServices()

func (*Env) Seed

func (e *Env) Seed() *errors.ServiceError

func (*Env) SetEnvironmentDefaults added in v0.2.0

func (e *Env) SetEnvironmentDefaults(flags *pflag.FlagSet) error

SetEnvironmentDefaults sets environment-specific flag defaults This is used for environment-specific behavior flags (e.g., verbose mode, OCM debug)

func (*Env) Teardown

func (e *Env) Teardown()

type EnvironmentImpl

type EnvironmentImpl interface {
	EnvironmentDefaults() map[string]string
	OverrideConfig(c *config.ApplicationConfig) error
	OverrideServices(s *Services) error
	OverrideDatabase(s *Database) error
	OverrideHandlers(c *Handlers) error
	OverrideClients(c *Clients) error
}

EnvironmentImpl defines a set of behaviors for an OCM environment. Each environment provides a set of flags for basic set/override of the environment and configuration functions for each component type.

type Handlers

type Handlers struct {
	AuthMiddleware auth.JWTMiddleware
}

type Services

type Services struct {
	// contains filtered or unexported fields
}

func (*Services) GetService

func (s *Services) GetService(name string) interface{}

func (*Services) SetService

func (s *Services) SetService(name string, service interface{})

Directories

Path Synopsis

Jump to