factories

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2026 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewClusterWithLabels

func NewClusterWithLabels(
	f *Factories, dbFactory db.SessionFactory, id string, labels map[string]string,
) (*api.Cluster, error)

NewClusterWithLabels creates a cluster with specific labels

func NewClusterWithObservedGeneration added in v0.2.0

func NewClusterWithObservedGeneration(
	f *Factories, dbFactory db.SessionFactory, id string,
	isAvailable, isReady bool, observedGeneration int32,
) (*api.Cluster, error)

NewClusterWithObservedGeneration creates a cluster with a specific observed_generation on its conditions. This is useful for testing observed_generation-based queries.

func NewClusterWithStatus

func NewClusterWithStatus(
	f *Factories, dbFactory db.SessionFactory, id string, isAvailable, isReady bool,
) (*api.Cluster, error)

NewClusterWithStatus creates a cluster with specific status conditions using the current time.

func NewClusterWithStatusAndLabels

func NewClusterWithStatusAndLabels(
	f *Factories, dbFactory db.SessionFactory, id string, isAvailable, isReady bool, labels map[string]string,
) (*api.Cluster, error)

NewClusterWithStatusAndLabels creates a cluster with both status conditions and labels

func NewClusterWithStatusAtTime added in v0.2.0

func NewClusterWithStatusAtTime(
	f *Factories, dbFactory db.SessionFactory, id string,
	isAvailable, isReady bool, conditionTime time.Time,
) (*api.Cluster, error)

NewClusterWithStatusAtTime creates a cluster with specific status conditions and custom timestamps. This is useful for testing time-based condition queries (e.g., last_updated_time < '...')

func NewNodePoolWithLabels

func NewNodePoolWithLabels(
	f *Factories, dbFactory db.SessionFactory, id string, labels map[string]string,
) (*api.NodePool, error)

NewNodePoolWithLabels creates a node pool with specific labels

func NewNodePoolWithStatus

func NewNodePoolWithStatus(
	f *Factories, dbFactory db.SessionFactory, id string, isAvailable, isReady bool,
) (*api.NodePool, error)

NewNodePoolWithStatus creates a node pool with specific status conditions using the current time.

func NewNodePoolWithStatusAndLabels

func NewNodePoolWithStatusAndLabels(
	f *Factories, dbFactory db.SessionFactory, id string, isAvailable, isReady bool, labels map[string]string,
) (*api.NodePool, error)

NewNodePoolWithStatusAndLabels creates a node pool with both status conditions and labels

func NewNodePoolWithStatusAtTime added in v0.2.0

func NewNodePoolWithStatusAtTime(
	f *Factories, dbFactory db.SessionFactory, id string,
	isAvailable, isReady bool, conditionTime time.Time,
) (*api.NodePool, error)

NewNodePoolWithStatusAtTime creates a node pool with specific status conditions and custom timestamps.

Types

type Factories

type Factories struct {
}

func (*Factories) NewCluster

func (f *Factories) NewCluster(id string) (*api.Cluster, error)

func (*Factories) NewClusterList

func (f *Factories) NewClusterList(name string, count int) ([]*api.Cluster, error)

func (*Factories) NewClusters

func (f *Factories) NewClusters(id string) (*api.Cluster, error)

Aliases for test compatibility

func (*Factories) NewClustersList

func (f *Factories) NewClustersList(name string, count int) ([]*api.Cluster, error)

func (*Factories) NewID

func (f *Factories) NewID() string

NewID generates a new unique identifier using KSUID with lowercase Base32 encoding. The resulting identifier is compatible with Kubernetes DNS-1123 subdomain naming requirements.

func (*Factories) NewNodePool

func (f *Factories) NewNodePool(id string) (*api.NodePool, error)

func (*Factories) NewNodePoolList

func (f *Factories) NewNodePoolList(name string, count int) ([]*api.NodePool, error)

func (*Factories) NewNodePools

func (f *Factories) NewNodePools(id string) (*api.NodePool, error)

Aliases for test compatibility

func (*Factories) NewNodePoolsList

func (f *Factories) NewNodePoolsList(name string, count int) ([]*api.NodePool, error)

Jump to